/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { ImageProps } from 'react-native';
import { StyledComponentProps } from '../../theme';
interface ComponentProps {
    shape?: string;
    size?: string;
}
export declare type AvatarProps = StyledComponentProps & ImageProps & ComponentProps;
export declare type AvatarElement = React.ReactElement<AvatarProps>;
/**
 * `Avatar` is a styled `Image` component.
 *
 * @extends React.Component
 *
 * @property {string} shape - Determines the shape of the component.
 * Can be `round`, `rounded` or `square`.
 * Default is `round`.
 *
 * @property {string} size - Determines the size of the component.
 * Can be `giant`, `large`, `medium`, `small`, or `tiny`.
 * Default is `medium`.
 *
 * @property ImageProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Avatar } from '../..';
 *
 * export const AvatarShowcase = (props) => (
 *   <Avatar source={require('path-to-assets/local-image.png')} />
 * );
 * ```
 *
 * @overview-example Remote Images
 *
 * ```
 * import React from 'react';
 * import { Avatar } from '../..';
 *
 * export const AvatarShowcase = (props) => (
 *   <Avatar source={{ uri: 'https://images.unsplash.com/photo-1494790108377-be9c29b29330' }} />
 * );
 * ```
 *
 * @overview-example Eva Styling
 *
 * ```
 * import React from 'react';
 * import { Avatar } from '../..';
 *
 * export const AvatarShowcase = (props) => (
 *   <Avatar
 *     source={require('path-to-assets/local-image.png')}
 *     size='large'
 *     shape='rounded'
 *   />
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { Avatar } from '../..';
 *
 * export const AvatarShowcase = (props) => (
 *   <Avatar
 *     style={styles.avatar}
 *     source={require('path-to-assets/local-image.png')}
 *   />
 * );
 *
 * const styles = StyleSheet.create({
 *   avatar: { width: 96, height: 96, borderRadius: 16 }
 * });
 * ```
 */
export declare class AvatarComponent extends React.Component<AvatarProps> {
    static styledComponentName: string;
    private getComponentStyle;
    render(): React.ReactElement<ImageProps>;
}
export declare const Avatar: React.ComponentClass<AvatarProps, any>;
export {};
