import React from 'react';
import { ListItem, } from '../list/listItem.component';
/**
 * `DrawerHeaderFooter` is a support component for `Drawer`.
 * Designed to be used as Header or Footer of `Drawer`.
 *
 * @extends React.Component
 *
 * @property {string} title - Determines the title of the DrawerHeaderFooter.
 *
 * @property {string} description - Determines the description of the DrawerHeaderFooter's title.
 *
 * @property {StyleProp<TextStyle>} titleStyle - Customizes title style.
 *
 * @property {StyleProp<TextStyle>} descriptionStyle - Customizes description style.
 *
 * @property {React.ReactNode} children - Determines React Children of the component.
 *
 * @property {(style: StyleType, index: number) => React.ReactElement<any>} accessory - Determines the accessory of the
 * component.
 *
 * @property {(style: StyleType, index: number) => React.ReactElement<ImageProps>} icon - Determines the icon of the
 * component.
 *
 * @property {(index: number, event: GestureResponderEvent) => React.ReactElement<ImageProps>} onPress - Emits when
 * component is pressed.
 *
 * @overview-example Simple Usage
 *
 * ```
 * // IMPORTANT: To use Icon component make sure to follow this guide:
 * // https://akveo.github.io/react-native-ui-kitten/docs/guides/eva-icons
 *
 * import React from 'react'
 * import { DrawerHeaderFooter, Icon } from '../..';
 *
 * const ProfileIcon = (style) => (
 *   <Icon {...style} name='person' />
 * );
 *
 * export const ProfileHeader = (props) => (
 *   <DrawerHeaderFooter title='John Doe' description='React Native Developer' icon={ProfileIcon} />
 * );
 * ```
 *
 * @overview-example With Accessory
 *
 * ```
 * // IMPORTANT: To use Icon component make sure to follow this guide:
 * // https://akveo.github.io/react-native-ui-kitten/docs/guides/eva-icons
 *
 * import React from 'react'
 * import { DrawerHeaderFooter, Icon } from '../..';
 *
 * const LogoutIcon = (style) => (
 *   <Icon {...style} name='log-out' />
 * );
 *
 * const LogoutButton = (style): React.ReactElement<ButtonProps> => (
 *   <Button style={style} icon={LogoutIcon} />
 * );
 *
 * export const ProfileHeader = (props) => (
 *   <DrawerHeaderFooter
 *     title='John Doe'
 *     description='React Native Developer'
 *     accessory={LogoutButton}
 *   />
 * );
 * ```
 *
 * @example Using Asset Icons
 *
 * ```
 * import React from 'react'
 * import { Image } from '../..';
 * import { DrawerHeaderFooter } from '../..';
 *
 * const ProfileIcon = (style) => (
 *   <Image style={style} source={require('path-to-assets/local-image.png')} />
 * );
 *
 * export const ProfileHeader = (props) => (
 *   <DrawerHeaderFooter title='John Doe' description='React Native Developer' icon={ProfileIcon} />
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react'
 * import { StyleSheet } from 'react-native';
 * import { DrawerHeaderFooter } from '../..';
 *
 * export const ProfileHeader = (props) => (
 *   <DrawerHeaderFooter
 *     style={styles.drawerHeader}
 *     titleStyle={styles.drawerHeaderTitle}
 *     descriptionStyle={styles.drawerHeaderDescription}
 *     title='John Doe'
 *     description='React Native Developer'
 *   />
 * );
 *
 * const styles = StyleSheet.create({
 *   drawerHeader: { backgroundColor: 'black' }
 *   drawerHeaderTitle: { color: 'white' }
 *   drawerHeaderDescription: { color: 'gray' }
 * });
 * ```
 */
export class DrawerHeaderFooter extends React.Component {
    render() {
        return (<ListItem {...this.props}/>);
    }
}
//# sourceMappingURL=drawerHeaderFooter.component.js.map