/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { View, } from 'react-native';
import { styled, } from '../../theme';
/**
 * `Layout` container component. Behaves like React Native `View`.
 * The key feature of using `Layout` instead of `View` is that
 * it automatically picks background color fitting to current theme.
 *
 * @extends React.Component
 *
 * @property {string} level - Determines background color level of component.
 * Can be `level='1'`, `level='2'`, `level='3'` or `level='4'`.
 *
 * @property {React.ReactElement<any> | React.ReactElement<any>[]} children - Determines the children of the component.
 *
 * @property ViewProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Layout, Text } from '../..';
 *
 * export const LayoutShowcase = (props) => (
 *   <Layout>
 *     <Text>Layout</Text>
 *   </Layout>
 * );
 * ```
 *
 * @overview-example Layout Levels
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { Layout, Text } from '../..';
 *
 * export const LayoutShowcase = (props) => (
 *   <Layout style={styles.container} level='4'>
 *     <Layout style={styles.container} level='3'>
 *       <Layout style={styles.container} level='2'>
 *         <Layout style={[styles.container, styles.contentContainer]}>
 *           <Text>Welcome to UI Kitten</Text>
 *         </Layout>
 *       </Layout>
 *     </Layout>
 *   </Layout>
 * );
 *
 * const styles = StyleSheet.create({
 *   container: { flex: 1, padding: 16 }
 *   contentContainer: { justifyContent: 'center', alignItems: 'center' }
 * });
 * ```
 *
 * @overview-example Eva Styling
 *
 * ```
 * import React from 'react';
 * import { Layout, Text } from '../..';
 *
 * export const LayoutShowcase = (props) => (
 *   <Layout level='2'>
 *     <Text>Layout</Text>
 *   </Layout>
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from '../..';
 * import { Layout, Text } from '../..';
 *
 * export const LayoutShowcase = (props) => (
 *   <Layout style={styles.container}>
 *     <Text>Layout</Text>
 *   </Layout>
 * );
 *
 * const styles = StyleSheet.create({
 *   container: { flex: 1, justifyContent: 'center', alignItems: 'center' },
 * });
 * ```
 */
export class LayoutComponent extends React.Component {
    render() {
        const _a = this.props, { style, themedStyle } = _a, derivedProps = __rest(_a, ["style", "themedStyle"]);
        return (<View {...derivedProps} style={[themedStyle, style]}/>);
    }
}
LayoutComponent.styledComponentName = 'Layout';
export const Layout = styled(LayoutComponent);
//# sourceMappingURL=layout.component.js.map