/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import { Text as RNText, } from 'react-native';
import { styled, } from '../../theme';
/**
 * Styled `Text` component.
 *
 * @extends React.Component
 *
 * @property {string} status - Determines the status of the component.
 * Can be `primary`, `success`, `info`, `warning` or `danger`.
 *
 * @property {string} children - Determines text of the component.
 *
 * @property {string} category - Determines the category of the component.
 * Can be `h1`, `h2`, `h3`, `h4`, `h5`, `h6`, `s1`, `s2`, `p1`, `p2`, `c1`, `c2`, `label`.
 * Default is `p1`.
 *
 * @property {string} appearance - Determines the appearance of the component.
 * Can be `default`, `alternative`, `hint`.
 * Default is `default`.
 *
 * @property TextComponentProps
 *
 * @property StyledComponentProps
 *
 * @overview-example Simple Usage
 *
 * ```
 * import React from 'react';
 * import { Text } from '../..';
 *
 * export const TextShowcase = (props) => (
 *   <Text>Sample Text</Text>
 * );
 * ```
 *
 * @overview-example Eva Styling
 *
 * ```
 * import React from 'react';
 * import { Text } from '../..';
 *
 * export const TextShowcase = (props) => (
 *   <Text
 *     appearance='hint'
 *     category='p2'
 *     status='success'>
 *     Sample Text
 *   </Text>
 * );
 * ```
 *
 * @example Inline Styling
 *
 * ```
 * import React from 'react';
 * import { StyleSheet } from 'react-native';
 * import { Text } from '../..';
 *
 * export const TextShowcase = (props) => (
 *   <Text style={styles.text}>Sample Text</Text>
 * );
 *
 * const styles = StyleSheet.create({
 *   text: { color: 'black', fontSize: 18 },
 * });
 * ```
 */
export class TextComponent extends React.Component {
    render() {
        const _a = this.props, { themedStyle, style } = _a, derivedProps = __rest(_a, ["themedStyle", "style"]);
        return (<RNText {...derivedProps} style={[themedStyle, style]}/>);
    }
}
TextComponent.styledComponentName = 'Text';
export const Text = styled(TextComponent);
//# sourceMappingURL=text.component.js.map